import 'package:core_location_fluttify/core_location_fluttify.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import 'options.dart';

/// 地图标记
abstract class Marker {
  /// 获取标题
  Future<String> get title;

  /// 获取副标题
  Future<String> get snippet;

  /// 获取定位信息
  Future<LatLng> get location;

  /// 获取自定义信息
  Future<String> get object;

  /// 删除marker
  Future<void> remove();

  /// 设置坐标
  Future<void> setCoordinate(LatLng coordinate);

  /// 设置可见性
  Future<void> setVisible(bool visible);

  /// 显示弹窗
  Future<void> showInfoWindow();

  /// 关闭弹窗
  Future<void> hideInfoWindow();

  /// 设置图标
  Future<void> setIcon(
    ImageProvider iconProvider,
    ImageConfiguration configuration,
  );

  /// 设置动画
  Future<void> startAnimation(MarkerAnimation animation);
}

/// 平滑移动点
abstract class SmoothMoveMarker {
  Future<void> remove();

  Future<void> stop();
}

/// 折线
abstract class Polyline {
  Future<void> remove();

  /// 重新设置折线点列表
  ///
  /// 可用于轨迹记录
  Future<void> setCoordinateList(List<LatLng> coordinateList);
}

/// 多边形
abstract class Polygon {
  Future<void> remove();

  Future<bool> contains(LatLng target);
}

/// 圆形
abstract class Circle {
  Future<void> remove();
}

/// 热力图
abstract class HeatmapOverlay {
  Future<void> remove();
}

/// 热力图
abstract class UrlTileOverlay {
  Future<void> remove();
}

/// 图片覆盖物
abstract class GroundOverlay {
  Future<void> remove();
}

/// 海量点
abstract class MultiPointOverlay {
  Future<void> remove();
}

/// 回放轨迹
abstract class PlaybackTrace {
  Future<void> remove();

  Future<void> stop();
}
